==> dython-0.6.6.tar.gz: dython-0.6.6/README.md <==
# Dython

[![PyPI Version](https://img.shields.io/pypi/v/dython.svg)](https://pypi.org/project/dython/)
[![Python Version](https://img.shields.io/pypi/pyversions/dython.svg)](https://pypi.org/project/dython/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/dython)](https://pypistats.org/packages/dython)
[![License](https://img.shields.io/pypi/l/dython)](https://github.com/shakedzy/dython/blob/master/LICENSE)

A set of **D**ata analysis tools in p**YTHON** 3.x.

Dython was designed with analysis usage in mind - meaning ease-of-use, functionality and readability are the core 
values of this library. Production-grade performance, on the other hand, were not considered.

## Documentation:
Modules documentation can be found on [shakedzy.xyz/dython](http://shakedzy.xyz/dython)

## Installation:
Dython can be installed directly using `pip`:
```
pip install dython
```
If you wish to install from source:
```
pip install git+https://github.com/shakedzy/dython.git
```

**Dependencies:** `numpy`, `pandas`, `seaborn`, `scipy`, `matplotlib`, `sklearn`

## Contributing:
Contributions are always welcomed - if you found something you can fix, or have an idea for a new feature, feel free to write it and open a pull request. Please make sure to go over the [contributions guidelines](https://github.com/shakedzy/dython/blob/master/CONTRIBUTING.md).

## Change log:
Change log is available, see [CHANGELOG.md](https://github.com/shakedzy/dython/blob/master/CHANGELOG.md).

## Related blogposts:
Learn more about some of the main methods of this library and their usage on 
[these blogposts](http://shakedzy.xyz/dython/related_blogposts).

==> dython-0.6.7.tar.gz: dython-0.6.7/README.md <==
# Dython

[![PyPI Version](https://img.shields.io/pypi/v/dython.svg)](https://pypi.org/project/dython/)
[![Python Version](https://img.shields.io/pypi/pyversions/dython.svg)](https://pypi.org/project/dython/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/dython)](https://pypistats.org/packages/dython)
[![License](https://img.shields.io/pypi/l/dython)](https://github.com/shakedzy/dython/blob/master/LICENSE)

A set of **D**ata analysis tools in p**YTHON** 3.x.

Dython was designed with analysis usage in mind - meaning ease-of-use, functionality and readability are the core 
values of this library. Production-grade performance, on the other hand, were not considered.

## Documentation:
Modules documentation can be found on [shakedzy.xyz/dython](http://shakedzy.xyz/dython)

## Installation:
Dython can be installed directly using `pip`:
```
pip install dython
```
If you wish to install from source:
```
pip install git+https://github.com/shakedzy/dython.git
```

**Dependencies:** `numpy`, `pandas`, `seaborn`, `scipy`, `matplotlib`, `sklearn`, `scikit-plot`

## Contributing:
Contributions are always welcomed - if you found something you can fix, or have an idea for a new feature, feel free to write it and open a pull request. Please make sure to go over the [contributions guidelines](https://github.com/shakedzy/dython/blob/master/CONTRIBUTING.md).

## Change log:
Change log is available, see [CHANGELOG.md](https://github.com/shakedzy/dython/blob/master/CHANGELOG.md).

## Related blogposts:
Learn more about some of the main methods of this library and their usage on 
[these blogposts](http://shakedzy.xyz/dython/related_blogposts).
